Learn R Programming

CNOGpro (version 1.1)

CNOGpro-package: CNOGpro - Copy Numbers of Genes in Prokaryotes

Description

Detects copy number variation in resequencing experiments

Arguments

Details

Package:
CNOGpro
Type:
Package
Version:
1.1
Date:
2015-01-12
License:
GPL-2
After mapping the reads from a resequencing experiment to a reference organism, CNOGpro allows the user to count coverage of the reference in sliding windows, normalize the counts based on observed GC-bias, and run two main models for inferring copy number variation and breakpoints - One approach using a Hidden Markov Model, and one using bootstrapping. The latter will also produce confidence intervals of the desired range around the observed copy number.

References

Manuscript forthcoming...