Learn R Programming

CNOGpro (version 1.1)

carsonella: CNV experiment of C. Carsonella ruddy (artificial data)

Description

This is an example object of class CNOGpro, as created by the CNOGpro method. The input to this file was a GenBank flat file (Acc. nr: CP003467), and a table of best-hit read locations from a resequencing experiment. The data were created by artificially duplicating one gene and removing another from the chromosome, and is meant for illustration purposes only. The reads were created by the ART sequencing simulator by Huang et al. (2011)

Usage

data(carsonella)

Arguments

Format

An object of class CNOGpro

Artificial data, produced by the author

References

Huang,W. et al. (2011) ART: a next-generation sequencing read simulator. Bioinformatics, 28, 593--594. Nakabachi,A. et al. (2013) Defensive bacteriome symbiont with a drastically reduced genome. Curr. Biol., 23, 1478 -- 1484

Examples

Run this code
data(carsonella)
summaryCNOGpro(carsonella)
plotCNOGpro(carsonella)

Run the code above in your browser using DataLab